@@ -16,6 +16,7 @@ from sklearn.preprocessing import LabelEncoder
 import sklearn.metrics as metrics
 from termcolor import colored
 from scipy import stats
+import pickle as pkl
 
 '''
 This declare DeepHit architecture:
@@ -97,19 +98,20 @@ class Model_DeepHit:
     def _build_net(self):
         with tf.variable_scope(self.name):
             #### PLACEHOLDER DECLARATION
-            self.mb_size     = tf.placeholder(tf.int32, [], name='batch_size')
-            self.lr_rate     = tf.placeholder(tf.float32, [], name='learning_rate')
-            self.keep_prob   = tf.placeholder(tf.float32, [], name='keep_probability')   #keeping rate
-            self.a           = tf.placeholder(tf.float32, [], name='alpha')
-            self.b           = tf.placeholder(tf.float32, [], name='beta')
-            self.c           = tf.placeholder(tf.float32, [], name='gamma')
+            #The name tf.placeholder is deprecated. Please use tf.compat.v1.placeholder instead.
+            self.mb_size     = tf.compat.v1.placeholder(tf.int32, [], name='batch_size')
+            self.lr_rate     = tf.compat.v1.placeholder(tf.float32, [], name='learning_rate')
+            self.keep_prob   = tf.compat.v1.placeholder(tf.float32, [], name='keep_probability')   #keeping rate
+            self.a           = tf.compat.v1.placeholder(tf.float32, [], name='alpha')
+            self.b           = tf.compat.v1.placeholder(tf.float32, [], name='beta')
+            self.c           = tf.compat.v1.placeholder(tf.float32, [], name='gamma')
 
-            self.x           = tf.placeholder(tf.float32, shape=[None, self.x_dim], name='inputs')
-            self.k           = tf.placeholder(tf.float32, shape=[None, 1], name='labels')     #event/censoring label (censoring:0)
-            self.t           = tf.placeholder(tf.float32, shape=[None, 1], name='timetoevents')
+            self.x           = tf.compat.v1.placeholder(tf.float32, shape=[None, self.x_dim], name='inputs')
+            self.k           = tf.compat.v1.placeholder(tf.float32, shape=[None, 1], name='labels')     #event/censoring label (censoring:0)
+            self.t           = tf.compat.v1.placeholder(tf.float32, shape=[None, 1], name='timetoevents')
 
-            self.fc_mask1    = tf.placeholder(tf.float32, shape=[None, self.num_Event, self.num_Category], name='mask1')  #for Loss 1
-            self.fc_mask2    = tf.placeholder(tf.float32, shape=[None, self.num_Category], name='mask2')  #for Loss 2 / Loss 3
+            self.fc_mask1    = tf.compat.v1.placeholder(tf.float32, shape=[None, self.num_Event, self.num_Category], name='mask1')  #for Loss 1
+            self.fc_mask2    = tf.compat.v1.placeholder(tf.float32, shape=[None, self.num_Category], name='mask2')  #for Loss 2 / Loss 3
 
 
             ##### SHARED SUBNETWORK w/ FCNETS
@@ -538,90 +540,48 @@ def impt_f_get_fc_mask3(time, meas_time, num_Category):
             mask[i,:(t+1)] = 1  #this excludes the last measurement time and includes the event time
     return mask
 
+# los function
+########## ADAPTED IMPORT FOR LOS
+def get_Normalization_los(dffeatures, data_stats): # only implemented standard, but can include max-min type in the future
+    ##print('get_Normalization_los')
+    data=dffeatures
+    for feat in dffeatures.columns:
+        if data_stats.loc[feat,'std'] !=0:
+            data[feat]=(dffeatures[feat] - data_stats.loc[feat,'mean'])/data_stats.loc[feat,'std']
+        else:
+            data[feat]=(dffeatures[feat] - data_stats.loc[feat,'mean'])
+    return np.asarray(data)
 
-def impt_import_dataset_SYNTHETIC(norm_mode='standard'):
-    #in_filename = './sample data/nbm/train.csv'
-    #df = pd.read_csv(in_filename, sep=',')
-    # orig df = pd_train_sml
-    df = load_dffromCsv('pd_train_sml.csv')
+
+def import_dataset_los(dflabel,dfval,dffeatures,data_stats,norm_mode=True):
+    
+    label           = np.asarray(dflabel)
+    time            = np.asarray(dfval)
+    ##print('norm_mode:', norm_mode, '<import_dataset_los>')
+    if norm_mode:
+        data            = get_Normalization_los(dffeatures,data_stats)
+    else:
+        data            = np.asarray(dffeatures)
+    ## print('data=', data)
     
-    label           = np.asarray(df[['icudeath']] + 1)
-    time            = np.asarray(df[['iculos']])
-    data            = np.asarray(df.iloc[:,8:])
-    data            = impt_f_get_Normalization(data, norm_mode)
-
     num_Category    = int(np.max(time) * 1.2)  #to have enough time-horizon
+    ## print('num_Category:', num_Category)
     num_Event       = int(len(np.unique(label))) #only count the number of events (do not count censoring as an event)
     
     x_dim           = np.shape(data)[1]
 
+    ##print('A')
     mask1           = impt_f_get_fc_mask2(time, label, num_Event, num_Category)
+    ##print('B')
     mask2           = impt_f_get_fc_mask3(time, -1, num_Category)
-
+    ##print('C')
     DIM             = (x_dim)
     DATA            = (data, time, label)
     MASK            = (mask1, mask2)
 
     return DIM, DATA, MASK
 
-
-  
-def impt_import_dataset_xliu(norm_mode='standard'):
-    #in_filename = './sample data/nbm/test.csv'
-    #df = pd.read_csv(in_filename, sep=',')
-    # orig df = pd_test_dummy
-    df = load_dffromCsv('pd_test_dummy.csv')
-    
-    label           = np.asarray(df[['icudeath']] + 1)
-    time            = np.asarray(df[['iculos']])
-    data            = np.asarray(df.iloc[:,8:])
-    data            = impt_f_get_Normalization(data, norm_mode)
-
-    num_Category    = int(np.max(time) * 1.2)  #to have enough time-horizon
-    num_Event       = int(len(np.unique(label))) #only count the number of events (do not count censoring as an event)
-    
-    x_dim           = np.shape(data)[1]
-
-    mask1           = impt_f_get_fc_mask2(time, label, num_Event, num_Category)
-    mask2           = impt_f_get_fc_mask3(time, -1, num_Category)
-
-    DIM             = (x_dim)
-    DATA            = (data, time, label)
-    MASK            = (mask1, mask2)
-
-    return DIM, DATA, MASK
-
-
-  
-def impt_import_dataset_METABRIC(norm_mode='standard'):
-    in_filename1 = './sample data/METABRIC/cleaned_features_final.csv'
-    in_filename2 = './sample data/METABRIC/label.csv'
-
-    df1 = pd.read_csv(in_filename1, sep =',')
-    df2 = pd.read_csv(in_filename2, sep =',')
-
-    data  = np.asarray(df1)
-    data  = impt_f_get_Normalization(data, norm_mode)
-    
-    time  = np.asarray(df2[['event_time']])
-    # time  = np.round(time/12.) #unit time = month
-    label = np.asarray(df2[['label']])
-
-    
-    num_Category    = int(np.max(time) * 1.2)        #to have enough time-horizon
-    num_Event       = int(len(np.unique(label)) - 1) #only count the number of events (do not count censoring as an event)
-
-    x_dim           = np.shape(data)[1]
-
-    mask1           = impt_f_get_fc_mask2(time, label, num_Event, num_Category)
-    mask2           = impt_f_get_fc_mask3(time, -1, num_Category)
-
-    DIM             = (x_dim)
-    DATA            = (data, time, label)
-    MASK            = (mask1, mask2)
-
-    return DIM, DATA, MASK
-###x other utilities used
+ 
 
 ### random with replace minibatches function    
 def f_get_minibatch(mb_size, x, label, time, mask1, mask2):
@@ -635,41 +595,49 @@ def f_get_minibatch(mb_size, x, label, time, mask1, mask2):
     m2_mb = mask2[idx, :].astype(np.float32) #fc_mask
     return x_mb, k_mb, t_mb, m1_mb, m2_mb
 
-### sequential minibatch without replacement
-def f_get_minibatch_seq(mb_size, x, label, time, mask1, mask2):
-    idx = range(np.shape(x)[0])
-    idx = idx[itr*mb_size: (itr+1)*mb_size]
- 
-    x_mb = x[idx, :].astype(np.float32)
-    k_mb = label[idx, :].astype(np.float32) # censoring(0)/event(1,2,..) label
-    t_mb = time[idx, :].astype(np.float32)
-    m1_mb = mask1[idx, :, :].astype(np.float32) #fc_mask
-    m2_mb = mask2[idx, :].astype(np.float32) #fc_mask
-    return x_mb, k_mb, t_mb, m1_mb, m2_mb
+def xbatchpredict(xdata,xfunc, n=10000):
+    xlength = len(xdata)
+    print("BatchSubmitPrediction, total size= " + str(xlength))
+    for xindex in range (0, xlength, n):
+        x_pred_xindex = xfunc(xdata[xindex: xindex + n, :])
+        if xindex == 0:
+            pred_x = x_pred_xindex
+        else:
+            pred_x = np.concatenate((pred_x, x_pred_xindex), axis=0)
+            print(np.shape(pred_x))
+    return pred_x 
 
-### batch predict for large sample prediction(memory issue)
-def xbatchpredict(xdata,xfunc, n=10000):
-    xlength = len(xdata)
-    print("BatchSubmitPrediction, total size= " + str(xlength))
-    for xindex in range (0, xlength, n):
-        x_pred_xindex = xfunc(xdata[xindex: xindex + n, :])
-        if xindex == 0:
-            pred_x = x_pred_xindex
-        else:
-            pred_x = np.concatenate((pred_x, x_pred_xindex), axis=0)
-            print(np.shape(pred_x))
-    return pred_x 
-  
-def xbatchpredict(xdata,xfunc, n=10000):
-    xlength = len(xdata)
-    print("BatchSubmitPrediction, total size= " + str(xlength))
-    for xindex in range (0, xlength, n):
-        x_pred_xindex = xfunc(xdata[xindex: xindex + n, :])
-        if xindex == 0:
-            pred_x = x_pred_xindex
-        else:
-            pred_x = np.concatenate((pred_x, x_pred_xindex), axis=0)
-            print(np.shape(pred_x))
-    return pred_x 
+def restoreModel(data, input_dims, network_settings,model_path):
+    pred=None
+    tf.compat.v1.reset_default_graph()
+    try:    
+        config = tf.compat.v1.ConfigProto()
+        config.gpu_options.allow_growth = True
+        with tf.Session() as sess:
+            #print('sess:', sess)
+            model2 = Model_DeepHit(sess, "DeepHit", input_dims, network_settings)
+            ##print('restored..')
+            saver = tf.compat.v1.train.Saver()
+            saver.restore(sess, model_path)
+            pred = model2.predict(data)
+            #print('pred=',pred)
+    except Exception as e:
+            print('error:', e)
+    return pred
   
+def final_prediction(pred):
+      categorization=None
+      if pred is None:
+        return 'N/A', 'N/A'
+      else:
+            pred1 = pred[:,0,:]
+            pred2 = pred[:,1,:]
+            pred3 = pred1 + pred2
+
+            predlosmean = np.multiply(pred3, np.arange(1,pred3.shape[1]+1,1))
+            xlos=predlosmean.cumsum(axis=1)[:,pred3.shape[1]-1]
+            categorization=1
+
+      return xlos, categorization 
+
   
\ No newline at end of file
